.. _install:

Installation
============


Source code
-----------

If a package is not available for your platform (or it's out of date) you
can install Livestreamer via source.

There are a few different methods to do this,
`pip <http://pip.readthedocs.org/en/latest/installing.html>`_ the Python package
manager, :command:`easy_install` the older package manager included with
`python-setuptools`_ or by checking out the latest code with
`Git <http://git-scm.com/downloads>`_.

Dependencies
------------


Starting as Service
-------------------
